@@ -15,13 +15,16 @@ use Readonly;
 Readonly::Scalar my $EMPTY_STR => q{};
 
 # Version.
-our $VERSION = 0.02;
+our $VERSION = 0.03;
 
 # Constructor.
 sub new {
 	my ($class, @params) = @_;
 	my $self = bless {}, $class;
 
+	# Callback.
+	$self->{'callback'} = undef;
+
 	# Config hash.
 	$self->{'config'} = {};
 
@@ -36,6 +39,11 @@ sub new {
 		err 'Bad \'config\' parameter.';
 	}
 
+	# Check callback.
+	if (defined $self->{'callback'} && ref $self->{'callback'} ne 'CODE') {
+		err 'Parameter \'callback\' isn\'t code reference.';
+	}
+
 	# Count of lines.
 	$self->{'count'} = 0;
 
@@ -174,6 +182,14 @@ Config::Dot - Module for simple configure file parsing.
 
 =over 8
 
+=item * B<callback>
+
+ Callback code for adding parameter.
+ Callback arguments are:
+ $key_ar - Reference to array with keys.
+ $value - Key value.
+ Default is undef.
+
 =item * B<config>
 
  Reference to hash structure with default config data.
@@ -220,6 +236,7 @@ Serialize 'config' hash to output.
 
  Mine:
          Bad 'config' parameter.
+         Parameter 'callback' isn't code reference.
 
  From Class::Utils::set_params():
          Unknown parameter '%s'.
@@ -281,6 +298,44 @@ Serialize 'config' hash to output.
  # key1=subkey1.value1
  # key2=value2
 
+=head1 EXAMPLE3
+
+ # Pragmas.
+ use strict;
+ use warnings;
+
+ # Modules.
+ use Config::Dot;
+ use Dumpvalue;
+
+ # Object.
+ my $struct_hr = Config::Dot->new(
+         'callback' => sub {
+                my ($key_ar, $value) = @_;
+                if ($key_ar->[0] eq 'key3' && $key_ar->[1] eq 'subkey1'
+                        && $value eq 'value3') {
+
+                        return 'FOOBAR';
+                }
+                return $value;
+         },
+ )->parse(<<'END');
+ key1=value1
+ key2=value2
+ key3.subkey1=value3
+ END
+
+ # Dump
+ my $dump = Dumpvalue->new;
+ $dump->dumpValues($struct_hr);
+
+ # Output:
+ # 0  HASH(0x84b98a0)
+ #    'key1' => 'value1',
+ #    'key2' => 'value2',
+ #    'key3' => HASH(0x8da3ab0)
+ #       'subkey1' => 'FOOBAR',
+
 =head1 DEPENDENCIES
 
 L<Class::Utils>,
@@ -293,6 +348,10 @@ L<Readonly>.
 
 L<Config::Utils>.
 
+=head1 REPOSITORY
+
+L<https://github.com/tupinek/Config-Dot>
+
 =head1 AUTHOR
 
 Michal Špaček L<mailto:skim@cpan.org>
@@ -305,6 +364,6 @@ BSD license.
 
 =head1 VERSION
 
-0.02
+0.03
 
 =cut
